@@ -12,7 +12,7 @@
 
 #define QT_FEATURE_webengine_pepper_plugins 1
 
-#define QT_FEATURE_webengine_proprietary_codecs -1
+#define QT_FEATURE_webengine_proprietary_codecs 1
 
 #define QT_FEATURE_webengine_kerberos -1
 
@@ -26,7 +26,7 @@
 
 #define QT_FEATURE_webengine_vulkan 1
 
-#define QT_FEATURE_webengine_vaapi -1
+#define QT_FEATURE_webengine_vaapi 1
 
 #define QT_FEATURE_webengine_arm64_udot_support -1
 
